aboutsummaryrefslogtreecommitdiff
path: root/src/primitives/transaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/primitives/transaction.h')
-rw-r--r--src/primitives/transaction.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/primitives/transaction.h b/src/primitives/transaction.h
index 18402ac453..5689d15bf7 100644
--- a/src/primitives/transaction.h
+++ b/src/primitives/transaction.h
@@ -213,7 +213,7 @@ public:
std::string ToString() const;
};
-class CTxinWitness
+class CTxInWitness
{
public:
CScriptWitness scriptWitness;
@@ -228,14 +228,14 @@ public:
bool IsNull() const { return scriptWitness.IsNull(); }
- CTxinWitness() { }
+ CTxInWitness() { }
};
class CTxWitness
{
public:
/** In case vtxinwit is missing, all entries are treated as if they were empty CTxInWitnesses */
- std::vector<CTxinWitness> vtxinwit;
+ std::vector<CTxInWitness> vtxinwit;
ADD_SERIALIZE_METHODS;
@@ -461,7 +461,7 @@ struct CMutableTransaction
uint256 GetHash() const;
};
-/** Compute the cost of a transaction, as defined by BIP 141 */
-int64_t GetTransactionCost(const CTransaction &tx);
+/** Compute the weight of a transaction, as defined by BIP 141 */
+int64_t GetTransactionWeight(const CTransaction &tx);
#endif // BITCOIN_PRIMITIVES_TRANSACTION_H